@@ -22,7 +22,7 @@ public:
 
 public Q_SLOTS:
     /* @p protocol being 'imap' 'smtp' or 'pop3' */
-    Q_SCRIPTABLE void test(const QString &server, const QString &protocol);
+    void test(const QString &server, const QString &protocol);
 
 Q_SIGNALS:
     /* returns the advised setting, @p result begin 'ssl' 'tls' or 'none'. */
@@ -31,10 +31,7 @@ Q_SIGNALS:
     /* returns if no connection is possible, test failed. */
     void testFail();
 
-private Q_SLOTS:
-    void testFinished(const QVector<int> &list);
-
 private:
+    void testFinished(const QList<int> &list);
     MailTransport::ServerTest *const m_serverTest;
 };
-
